@@ -1,14 +1,14 @@
 package Pod::Weaver::Config::Assembler;
-{
-  $Pod::Weaver::Config::Assembler::VERSION = '4.006';
-}
+# ABSTRACT: Pod::Weaver-specific subclass of Config::MVP::Assembler
+$Pod::Weaver::Config::Assembler::VERSION = '4.012';
 use Moose;
 extends 'Config::MVP::Assembler';
 with 'Config::MVP::Assembler::WithBundles';
-# ABSTRACT: Pod::Weaver-specific subclass of Config::MVP::Assembler
 
 use String::RewritePrefix;
 
+use namespace::autoclean;
+
 sub expand_package {
   my $str = $_[1];
 
@@ -23,7 +23,7 @@ sub expand_package {
   );
 }
 
-no Moose;
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -38,7 +38,7 @@ Pod::Weaver::Config::Assembler - Pod::Weaver-specific subclass of Config::MVP::A
 
 =head1 VERSION
 
-version 4.006
+version 4.012
 
 =head1 AUTHOR
 
@@ -46,7 +46,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2015 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
