@@ -1,15 +1,23 @@
 package Pod::Weaver::Role::Finalizer;
-{
-  $Pod::Weaver::Role::Finalizer::VERSION = '4.006';
-}
+# ABSTRACT: something that goes back and finishes up after main weaving is over
+$Pod::Weaver::Role::Finalizer::VERSION = '4.012';
 use Moose::Role;
 with 'Pod::Weaver::Role::Plugin';
-# ABSTRACT: something that goes back and finishes up after main weaving is over
 
+use namespace::autoclean;
+
+#pod =head1 IMPLEMENTING
+#pod
+#pod The Finalizer role indicates that a plugin will be used to post-process the
+#pod output document hashref after section weaving is completed.  The plugin must
+#pod provide a C<finalize_document> method which will be called as follows:
+#pod
+#pod   $finalizer_plugin->finalize_document($document, \%input);
+#pod
+#pod =cut
 
 requires 'finalize_document';
 
-no Moose::Role;
 1;
 
 __END__
@@ -24,7 +32,7 @@ Pod::Weaver::Role::Finalizer - something that goes back and finishes up after ma
 
 =head1 VERSION
 
-version 4.006
+version 4.012
 
 =head1 IMPLEMENTING
 
@@ -40,7 +48,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2015 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
