@@ -1,15 +1,25 @@
 package Pod::Weaver::Role::Section;
-{
-  $Pod::Weaver::Role::Section::VERSION = '4.006';
-}
+# ABSTRACT: a plugin that will get a section into a woven document
+$Pod::Weaver::Role::Section::VERSION = '4.012';
 use Moose::Role;
 with 'Pod::Weaver::Role::Plugin';
-# ABSTRACT: a plugin that will get a section into a woven document
 
+use namespace::autoclean;
+
+#pod =head1 IMPLEMENTING
+#pod
+#pod This role is used by plugins that will append sections to the output document.
+#pod They must provide a method, C<weave_section> which will be invoked like this:
+#pod
+#pod   $section_plugin->weave_section($output_document, \%input);
+#pod
+#pod They are expected to append their output to the output document, but they are
+#pod free to behave differently if it's needed to do something really cool.
+#pod
+#pod =cut
 
 requires 'weave_section';
 
-no Moose::Role;
 1;
 
 __END__
@@ -24,7 +34,7 @@ Pod::Weaver::Role::Section - a plugin that will get a section into a woven docum
 
 =head1 VERSION
 
-version 4.006
+version 4.012
 
 =head1 IMPLEMENTING
 
@@ -42,7 +52,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2015 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
